================
Related projects
================

This is a non-exhaustive list of related, open-source projects that users of ``orix``
might find useful:

- `pyxem <https://pyxem.readthedocs.io>`_: Python library for multi-dimensional
  diffraction microscopy. ``pyxem`` depends on ``orix`` for handling of crystal
  orientations.
- `diffsims <https://diffsims.readthedocs.io>`_: Python library for simulating
  diffraction. ``diffsims`` depends on ``orix`` for orientation sampling and handling of
  crystal orientations and directions.
- `kikuchipy <https://kikuchipy.org>`_: Python library for processing and analysis of
  electron backscatter diffraction (EBSD) patterns. ``kikuchipy`` depends on ``orix``
  for orientation sampling and handling of crystal orientations and directions.
- `MTEX <https://mtex-toolbox.github.io>`_: MATLAB toolbox for analyzing and
  modelling crystallographic textures by means of EBSD or pole figure data.
- `DefDAP <https://defdap.readthedocs.io/en/latest/?badge=latest>`_: Python package for
  correlating EBSD and high-resolution digital image correlation data.
- `numpy-quaternion <https://github.com/moble/quaternion>`_: Python package that adds a
  built in quaternion data dtype to ``numpy``. ``orix`` depends on ``numpy-quaternion``
  for quaternion multiplication.
- `texture <https://github.com/usnistgov/texture>`_: Python scripts for analysis of
  crystallographic texture.
- `pymicro <https://pymicro.readthedocs.io>`_: Python package to work with material
  microstructures and 3D data sets.
